import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::AIOps::InvestigationGroup Resource Type
 */
export declare class InvestigationGroup extends pulumi.CustomResource {
    /**
     * Get an existing InvestigationGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InvestigationGroup;
    /**
     * Returns true if the given object is an instance of InvestigationGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InvestigationGroup;
    readonly arn: pulumi.Output<string>;
    /**
     * An array of key-value pairs of notification channels to apply to this resource.
     */
    readonly chatbotNotificationChannels: pulumi.Output<outputs.aiops.InvestigationGroupChatbotNotificationChannel[] | undefined>;
    readonly createdAt: pulumi.Output<string>;
    readonly createdBy: pulumi.Output<string>;
    /**
     * An array of cross account configurations.
     */
    readonly crossAccountConfigurations: pulumi.Output<outputs.aiops.InvestigationGroupCrossAccountConfiguration[] | undefined>;
    readonly encryptionConfig: pulumi.Output<outputs.aiops.InvestigationGroupEncryptionConfigMap | undefined>;
    /**
     * Investigation Group policy
     */
    readonly investigationGroupPolicy: pulumi.Output<string | undefined>;
    /**
     * Flag to enable cloud trail history
     */
    readonly isCloudTrailEventHistoryEnabled: pulumi.Output<boolean | undefined>;
    readonly lastModifiedAt: pulumi.Output<string>;
    readonly lastModifiedBy: pulumi.Output<string>;
    readonly name: pulumi.Output<string>;
    /**
     * The number of days to retain the investigation group
     */
    readonly retentionInDays: pulumi.Output<number | undefined>;
    readonly roleArn: pulumi.Output<string | undefined>;
    readonly tagKeyBoundaries: pulumi.Output<string[] | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a InvestigationGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: InvestigationGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InvestigationGroup resource.
 */
export interface InvestigationGroupArgs {
    /**
     * An array of key-value pairs of notification channels to apply to this resource.
     */
    chatbotNotificationChannels?: pulumi.Input<pulumi.Input<inputs.aiops.InvestigationGroupChatbotNotificationChannelArgs>[]>;
    /**
     * An array of cross account configurations.
     */
    crossAccountConfigurations?: pulumi.Input<pulumi.Input<inputs.aiops.InvestigationGroupCrossAccountConfigurationArgs>[]>;
    encryptionConfig?: pulumi.Input<inputs.aiops.InvestigationGroupEncryptionConfigMapArgs>;
    /**
     * Investigation Group policy
     */
    investigationGroupPolicy?: pulumi.Input<string>;
    /**
     * Flag to enable cloud trail history
     */
    isCloudTrailEventHistoryEnabled?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    /**
     * The number of days to retain the investigation group
     */
    retentionInDays?: pulumi.Input<number>;
    roleArn?: pulumi.Input<string>;
    tagKeyBoundaries?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
